#
# spec file for package python-PyLaTeX
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-PyLaTeX
Version:        1.4.2
Release:        1.6
Summary:        A Python library for creating LaTeX files and snippets
License:        MIT
URL:            https://github.com/JelteF/PyLaTeX
Source:         https://github.com/JelteF/PyLaTeX/archive/v%{version}.tar.gz#/PyLaTeX-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ordered-set
Requires:       texlive-latex
Recommends:     python-matplotlib
Recommends:     python-numpy
Recommends:     python-quantities
Recommends:     tex(amsmath.sty)
Recommends:     tex(booktabs.sty)
Recommends:     tex(cleveref.sty)
Recommends:     tex(color.sty)
Recommends:     tex(enumitem.sty)
Recommends:     tex(fancyhdr.sty)
Recommends:     tex(fontenc.sty)
Recommends:     tex(geometry.sty)
Recommends:     tex(graphicx.sty)
Recommends:     tex(hyperref.sty)
Recommends:     tex(inputenc.sty)
Recommends:     tex(lastpage.sty)
Recommends:     tex(lmodern.sty)
Recommends:     tex(longtable.sty)
Recommends:     tex(ltablex.sty)
Recommends:     tex(mdframed.sty)
Recommends:     tex(microtype.sty)
Recommends:     tex(multirow.sty)
Recommends:     tex(parskip.sty)
Recommends:     tex(pgfplots.sty)
Recommends:     tex(ragged2e.sty)
Recommends:     tex(siunitx.sty)
Recommends:     tex(subcaption.sty)
Recommends:     tex(tabu.sty)
Recommends:     tex(tabularx.sty)
Recommends:     tex(textcomp.sty)
Recommends:     tex(textpos.sty)
Recommends:     tex(tikz.sty)
Recommends:     tex(xcolor.sty)
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ordered-set}
BuildRequires:  %{python_module pytest}
BuildRequires:  texlive-latex
BuildRequires:  %{python_module matplotlib if (%python-base without python36-base)}
BuildRequires:  %{python_module numpy if (%python-base without python36-base)}
BuildRequires:  %{python_module quantities  if (%python-base without python36-base)}
BuildRequires:  tex(amsmath.sty)
BuildRequires:  tex(booktabs.sty)
BuildRequires:  tex(cleveref.sty)
BuildRequires:  tex(color.sty)
BuildRequires:  tex(enumitem.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(fontenc.sty)
BuildRequires:  tex(geometry.sty)
BuildRequires:  tex(graphicx.sty)
BuildRequires:  tex(hyperref.sty)
BuildRequires:  tex(inputenc.sty)
BuildRequires:  tex(lastpage.sty)
BuildRequires:  tex(lmodern.sty)
BuildRequires:  tex(longtable.sty)
BuildRequires:  tex(ltablex.sty)
BuildRequires:  tex(mdframed.sty)
BuildRequires:  tex(microtype.sty)
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(parskip.sty)
BuildRequires:  tex(pgfplots.sty)
BuildRequires:  tex(ragged2e.sty)
BuildRequires:  tex(siunitx.sty)
BuildRequires:  tex(subcaption.sty)
BuildRequires:  tex(tabu.sty)
BuildRequires:  tex(tabularx.sty)
BuildRequires:  tex(textcomp.sty)
BuildRequires:  tex(textpos.sty)
BuildRequires:  tex(tikz.sty)
BuildRequires:  tex(xcolor.sty)
# /SECTION
%python_subpackages

%description
PyLaTeX is a Python library for creating and compiling LaTeX files.

%prep
%autosetup -p1 -n PyLaTeX-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pylatex
%{python_sitelib}/PyLaTeX-%{version}.dist-info

%changelog
* Fri Feb 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4.2:
  * Add `.Chapter` in ``__init__.py``
  * Fix installation on Python 3.12
- Drop patch skip-optional-dependencies-test.patch, no longer required.
- Switch to pyproject macros.
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Some optional dependencies not available for the python36 flavor:
  * add skip-optional-dependencies-test.patch
  * don't install numpy, matplotlib and quantities for python36
    (NumPy 1.20 does not provide a Python 3.6 build on TW: NEP 29)
* Sun Jan 10 2021 andy great <andythe_great@pm.me>
- Update to version 1.4.1.
  * Fixes regression in 1.4.0 where empty ``geometry_options``
    would throw an error.
- Updates for version 1.4.0
  * Add ``Fragment`` class which is a ``Container`` without any
    LaTeX code surrounding its content.
  * Escape newlines in ``ContainerCommand``
  * Fix bug where the geometry options were not applied in some
    cases
  * Remove denose.patch, fixed.
* Tue Sep  1 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.4:
  * Use known working versions for Python 3.5 and lower of ordered-set
    dependency
  * The 'at' parameter for TikZNode should now work.
  * Use a different temporary directory per user.
* Mon Aug  3 2020 Matej Cepl <mcepl@suse.com>
- Add denose.patch removing nose dependency (gh#JelteF/PyLaTeX#294).
* Mon Jun  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.2
  * On python 3.6+ support multhreaded use of PyLaTeX, by not calling
    os.chdir
* Fri Nov  8 2019 Todd R <toddrme2178@gmail.com>
- Initial version
